# puppet-enc-common

This has the common elements across the Puppet ENC project. This includes constants and database definitions and tables.

## Installation

```python
pip install puppet-enc-common
```

## Usage

```python
from puppet_enc_common.database import ...
from puppet_enc_common.constants import ...
from puppet_enc_common.globals import ...
```